@@ -11,7 +11,6 @@
 #include "wrplugin.h"
 
 WrSink::WrSink(const PluginInterface *interface) : PluginAction(interface) {
-    ready = false;
     image = QImage(":/images/globe.png");
     image = image.scaledToHeight(48, Qt::SmoothTransformation);
 }
@@ -25,10 +24,6 @@ void WrSink::clickAction(QWidget *parentWindow) {
     win->show();
 }
 
-bool WrSink::isReady() {
-    return true;
-}
-
 void WrSink::setPlugin(WrPlugin *plugin) {
     this->plugin = plugin;
 }
