@@ -8,7 +8,7 @@
 
 class WrPlugin;
 
-class WrSink : public QObject, public PluginAction
+class WrSink : public PluginAction
 {
     Q_OBJECT
 public:
@@ -17,12 +17,13 @@ public:
     QString getName() {return "Webrequest sink";}
     QString getText() {return "Search the Web";}
     QString getInformativeText();
-    bool isReady();
     void clickAction(QWidget *parentWindow);
     void setPlugin(WrPlugin* plugin);
     QImage getImage();
     // other
     QString barcodeText;
+signals:
+    void isReady();
 private:
     bool ready;
     QString buttonText;
